#
# spec file for package med-tools
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover 11

%bcond_without python_bindings
%bcond_with    mpi

Name:           med-tools
Summary:        A library to store and exchange meshed data
License:        LGPL-3.0-only
Group:          Productivity/Graphics/Other
Version:        5.0.0
Release:        1.1
URL:            https://www.salome-platform.org/
# Download server is unreachable except for specific user-agents, causing issues with bots
# curl -A MozillaFirefox https://files.salome-platform.org/Salome/medfile/med-%{version}.tar.bz2
# sha256sum 267e76d0c67ec51c10e3199484ec1508baa8d5ed845c628adf660529dce7a3d4
Source0:        med-%{version}.tar.bz2
# PATCH-FIX-OPENSUSE
Patch0:         fix-cmakefiles.patch
# PATCH-FIX-OPENSUSE
Patch1:         0003-Avoid-format-warnings-on-64-bit.patch
# PATCH-FIX-OPENSUSE
Patch2:         use_installed_python_modules_for_tests.patch
# PATCH-FIX-OPENSUSE
Patch3:         Fix-no_return_in_nonvoid_function.patch
# PATCH-FIX-OPENSUSE
Patch4:         0001-Fix-AppendOutput-signature-for-Swig-4.3.patch
# PATCH-FIX-UPSTREAM
Patch5:         https://src.fedoraproject.org/rpms/med/raw/rawhide/f/hdf5-1.14.patch#/med-tools-hdf1_14.patch
# PATCH-FIX-UPSTREAM rebase based on ref:https://src.fedoraproject.org/rpms/med/blob/rawhide/f/med-py3.13.patch
Patch6:         med-tools-python3_13.patch
# PATCH-FIX-UPSTREAM
Patch7:         https://src.fedoraproject.org/rpms/med/raw/rawhide/f/med-gcc15.patch#/med-tools-gcc15.patch
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires:  gcc-fortran
BuildRequires:  hdf5-devel >= 1.12.1
BuildRequires:  make
BuildRequires:  zlib-devel
%if %{with python_bindings}
BuildRequires:  python3-devel
BuildRequires:  swig >= 4.1
%endif
# test suite fails and we don't build FreeCAD on 32bit either anymore
ExcludeArch:    %ix86

%description
MED-fichier (Modélisation et Echanges de Données,
in English Modelisation and Data Exchange) is a library
to store and exchange meshed data or computation results.
It uses the HDF5 file format to store the data.

%package -n libmedC%{sover}
Summary:        C++ API for the MED mesh data library
Group:          System/Libraries

%description -n libmedC%{sover}
MED-fichier (Modélisation et Echanges de Données,
in English Modelisation and Data Exchange) is a library
to store and exchange meshed data or computation results.
It uses the HDF5 file format to store the data.

%package -n libmedfwrap%{sover}
Summary:        Fortran API for the MED mesh data library
Group:          System/Libraries

%description -n libmedfwrap%{sover}
MED-fichier (Modélisation et Echanges de Données,
in English Modelisation and Data Exchange) is a library
to store and exchange meshed data or computation results.
It uses the HDF5 file format to store the data.

%package -n libmed%{sover}
Summary:        A library to store and exchange meshed data
Group:          System/Libraries

%description -n libmed%{sover}
MED-fichier (Modélisation et Echanges de Données,
in English Modelisation and Data Exchange) is a library
to store and exchange meshed data or computation results.
It uses the HDF5 file format to store the data.

%package -n libmed-python
Summary:        Python wrapper for the MED library
Group:          Development/Languages/Python

%description -n libmed-python
MED-fichier (Modélisation et Echanges de Données,
in English Modelisation and Data Exchange) is a library
to store and exchange meshed data or computation results.
It uses the HDF5 file format to store the data.

This package contains the python bindings

%package -n libmed-devel
Requires:       hdf5-devel >= 1.12.1
Requires:       libmed%{sover} = %{version}
Requires:       libmedC%{sover} = %{version}
Requires:       libmedimport0 = %{version}
Summary:        Libmed development files
Group:          Development/Libraries/C and C++

%description -n libmed-devel
MED-fichier (Modélisation et Echanges de Données,
in English Modelisation and Data Exchange) is a library
to store and exchange meshed data or computation results.
It uses the HDF5 file format to store the data.

%package -n libmedimport0
Summary:        MED import Library
Group:          System/Libraries

%description -n libmedimport0
MED-fichier (Modélisation et Echanges de Données,
in English Modelisation and Data Exchange) is a library
to store and exchange meshed data or computation results.
It uses the HDF5 file format to store the data.

%package  doc
Summary:        MED documentation
Group:          Documentation/HTML
BuildArch:      noarch

%description  doc
MED-fichier (Modélisation et Echanges de Données,
in English Modelisation and Data Exchange) is a library
to store and exchange meshed data or computation results.
It uses the HDF5 file format to store the data.

%prep
%autosetup -p1 -n med-%{version}

# Fix file not utf8
iconv --from=ISO-8859-1 --to=UTF-8 ChangeLog > ChangeLog.new && \
touch -r ChangeLog ChangeLog.new && \
mv ChangeLog.new ChangeLog

%build
%cmake \
 -DMEDFILE_BUILD_PYTHON:BOOL=%{?with_python_bindings:ON}%{!?with_python_bindings:OFF} \
 -DMEDFILE_USE_MPI:BOOL=%{?with_mpi:ON}%{!?with_mpi:OFF} \
 -DMEDFILE_INSTALL_DOC:BOOL=ON

%cmake_build

%install
%cmake_install

# drop tests
rm -rf %buildroot/usr/bin/test*

# fix bash tag
sed -i -e 's,/usr/bin/env wish,/usr/bin/wish,' %buildroot/usr/bin/xmdump*

# move documentation
mkdir -p %{buildroot}/%{_docdir}
mv %{buildroot}/%{_datadir}/doc/med* %{buildroot}/%{_docdir}/med-tools

# add missing symlinks, install tries to generate these outside the buildroot
ln -sf mdump3 %{buildroot}/usr/bin/mdump
ln -sf xmdump3 %{buildroot}/usr/bin/xmdump

%fdupes %{buildroot}%{_datadir}
%fdupes %{buildroot}%{_includedir}
%if %{with python_bindings}
%fdupes %{buildroot}%{python_sitearch}
%endif

%check
cd build
export LC_ALL=C.utf8
export LD_LIBRARY_PATH=$LD_LIBRARY_PATH:%{buildroot}%{_libdir}
export PYTHONPATH=$PYTHONPATH:%{buildroot}%{python3_sitearch}
%make_build test ARGS="--output-on-failure"

%ldconfig_scriptlets -n libmed%{sover}
%ldconfig_scriptlets -n libmedC%{sover}
%ldconfig_scriptlets -n libmedfwrap%{sover}
%ldconfig_scriptlets -n libmedimport0

%files
%{_bindir}/mdump*
%{_bindir}/medconforme
%{_bindir}/medimport
%{_bindir}/xmdump*

%files -n libmed%{sover}
%{_libdir}/libmed.so.*

%files -n libmed-devel
%{_datadir}/cmake/*
%{_includedir}/*
%{_libdir}/*.so

%files -n libmedC%{sover}
%{_libdir}/libmedC.so.*

%files -n libmedfwrap%{sover}
%{_libdir}/libmedfwrap.so.*

%files -n libmedimport0
%{_libdir}/libmedimport.so.*

%if %{with python_bindings}
%files -n libmed-python
%{_libdir}/python*
%endif

%files doc
%{_docdir}/med-tools

%changelog
* Tue Mar 25 2025 Atri Bhattacharya <badshah400@gmail.com>
- Drop full URL for source tarball as the upstream web-server is
  intermittently unreachable and causes issues with Factory bots
  (add sha256sum of tarball as comment for optional verification).
* Fri Mar 14 2025 Atri Bhattacharya <badshah400@gmail.com>
- Add patches taken from Fedora:
  * med-tools-hdf1_14.patch: Allow compatiblity with HDF5 1.14.
  * med-tools-python3_13.patch: Compatibility with python 3.13.
  * med-tools-gcc15.patch: Fix build against GCC 15.
- Re-enable building against python 3.13.
* Fri Mar  7 2025 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to 5.0.0:
  * No upstream release notes.
- Rebase patches:
  * Fix-no_return_in_nonvoid_function.patch
- Remove obsolete patches:
  * hdf5-1.12.patch
- Add patches:
  * 0001-Fix-AppendOutput-signature-for-Swig-4.3.patch
* Mon Mar 11 2024 Bernhard Wiedemann <bwiedemann@suse.com>
- run fdupes during %%install
* Wed Aug 17 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 4.1.1
  * Doc files
  * s390x support added
  * Joints are now correctly displayed in mdump
  * Build system update
- Add patch from Arch to fix build with newer hdf versions:
  * hdf5-1.12.patch
* Sat Apr  9 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Revert the silent change to symlinks again.
- Use %%docdir instead of %%datadir/doc/packages, everywhere.
* Fri Apr  1 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Be more careful with fdupes to ensure we don't link across
  boundaries.
* Thu Mar 31 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Use hardlinks for fdupes call. Avoids dangling symlinks when
  files from devel package reference debugsource an vice-versa.
* Wed Jan  6 2021 Wang Jun <jgwang@suse.com>
- Fix no-return-in-nonvoid-function issue
  * Fix-no_return_in_nonvoid_function.patch
* Mon Jan  4 2021 Wang Jun <jgwang@suse.com>
- Update to version 4.1.0
  * Allows creation of 3.y file by MEDfileVersionOpen
  * Development of a new mode of access to the content of a control
  * Typing corrections in error messages in med-int = long configuration
  * Creation of an mdump4 using the new functions for quick access to
    lists of entities/geo fields.
  * Medimport update
  * Update doxygen version and documentation fixes
  * Updating CMake files by applying various patches
  * Possibility to define -DMED_MEDINT_TYPE = {int | long | long long (WINDOWS)}
    for the construction in cmake
  * Unicode management for MED file names under windows (Cmake option off by default)
  * Correction of a typing bug of med_idt for opening fct f77 in // * mode
- Drop these patches which merged into upstream
  * 0001-Fix-error-message-concatenation.patch
  * 0002-Return-this-from-operator-in-medenum-python-wrapper.patch
  * 0004-Fix-allocation-for-MEDfileName-consider-trailing-nul.patch
  * 0005-Respect-DESTDIR-when-byte-compiling-python-code.patch
- Modify these patches
  * fix-cmakefiles.patch
  * 0003-Avoid-format-warnings-on-64-bit.patch
  * use_installed_python_modules_for_tests.patch
* Tue Nov  5 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Fix failing python tests due to different filesystem layout of built
  and installed modules, add use_installed_python_modules_for_tests.patch
* Wed Feb 20 2019 Adrian Schröter <adrian@suse.de>
- drop hdf5-devel 1.8 deps
- drop dependency to main package from lib package
* Fri Feb 15 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Fix warnings, build
  * Add 0001-Fix-error-message-concatenation.patch
  * Add 0002-Return-this-from-operator-in-medenum-python-wrapper.patch
  * Add 0003-Avoid-format-warnings-on-64-bit.patch
  * Add 0005-Respect-DESTDIR-when-byte-compiling-python-code.patch
- Fix OOB access in python wrapper
  * Add 0004-Fix-allocation-for-MEDfileName-consider-trailing-nul.patch
- Reenable python bindings
* Fri Feb 15 2019 Jan Engelhardt <jengelh@inai.de>
- Update descriptions.
* Fri Feb 15 2019 Adrian Schröter <adrian@suse.de>
- disable python bindings for now, they cause test suite errors in
  med-tools testsuite. Also generated bindings cause post-build-check
  failures in tumbleweed due to incomplete generated functions.
* Tue Feb 12 2019 Adrian Schröter <adrian@suse.de>
- update to version 4.0.0
  * details can be found in Changelog in a ridicolous english accent
  * switching to python3
  * switching to HDF5 1.10
  * soversion is 11 now
- using cmake build system
  * fixing build/installation in fix-cmakefiles.patch
- new Fortran bindings subpackage
- drop tests package, run them in %%check instead
* Tue May  8 2018 adrian@suse.de
- update to version 3.3.1
  * french(!) ChangeLog file is included
* Tue Apr 17 2018 jengelh@inai.de
- Fix RPM groups, make documentation noarch and not dependent on
  the runtime, use find -delete, and drop redundant setting of
  C(XX)FLAGS.
* Tue Apr 10 2018 adrian@suse.de
- explicit require hdf5-1_8-devel
* Wed Feb  7 2018 adrian@suse.de
- use hdf5-1_8 to avoid incompatible on disk format
* Sun Jun 11 2017 adrian@suse.de
- enable swig to fix gcc-7 builds
* Wed Jun  7 2017 adrian@suse.de
- update to 3.2.1
- enable python bindings
* Sun Oct 14 2012 scorot@free.fr
- update to version 3.0.5
  * No ChangeLog available
- put examples and test cases in a separate package
* Tue Jul  3 2012 scorot@free.fr
- spec file reformating and cleanup
- move unwanted dirs under %%%%bindir to %%%%libdir
* Mon Nov  9 2009 andrea@opensuse.org
- new package
